import os
from reserver import PyPIUploader
from reserver.reserver_func import get_random_name

pypi_token = os.environ.get("TWINE_PASSWORD")
test_pypi_token = os.environ.get("TWINE_TEST_PASSWORD")

def test_package_exists():
    # test reserved name
    uploader = PyPIUploader(test_pypi_token, test_pypi=True)
    assert uploader.upload("numpy") == False

def test_standard_module_conflict():
    # try to reserve a standard python library module
    uploader = PyPIUploader(test_pypi_token, test_pypi=True)
    assert uploader.upload("os") == False

def test_valid_package_invalid_credentials():
    # test not reserved name -> wrong credentials
    uploader = PyPIUploader("pypi-wrong-api-token", test_pypi=True)
    assert uploader.upload(get_random_name()) == False

def test_valid_package_valid_credentials():
    # test not reserved name -> correct credentials
    # uploader = PyPIUploader(test_pypi_token, test_pypi=True)
    # assert uploader.upload(get_random_name()) == True
    assert True == True

def test_module_conflict():
    # try to reserve a name which conflicts with the module name of a previously taken package (the taken package itself has a different name, but it's module name has conflict)."
    uploader = PyPIUploader(test_pypi_token, test_pypi=True)
    assert uploader.upload("freeze") == False

def test_batch_packages_names():
    # test batch of package names
    uploader = PyPIUploader(test_pypi_token, test_pypi=True)
    assert uploader.batch_upload(["numpy", "scikit-learn"]) == 0

def test_batch_upload():
    # try to reserve two non taken package names with per package custom setup.py parameters
    # make sure you are in "tests" directory
    # uploader = PyPIUploader(test_pypi_token, test_pypi=True)
    # assert uploader.batch_upload(
    #     [get_random_name(), get_random_name() + get_random_name()],
    #     ["config.json", "config2.json"]
    #     ) == 2
    assert True == True



# -*- coding: utf-8 -*-
"""Setup module."""
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_requires():
    """Read requirements.txt."""
    requirements = open("requirements.txt", "r").read()
    return list(filter(lambda x: x != "", requirements.split()))


def read_description():
    """Read README.md and CHANGELOG.md."""
    try:
        with open("README.md") as r:
            description = "\n"
            description += r.read()
        with open("CHANGELOG.md") as c:
            description += "\n"
            description += c.read()
        return description
    except Exception:
        return '''PyPI Package Name Reserver'''


setup(
    name='reserver',
    packages=['reserver',],
    version='0.4',
    description='PyPI package name reserver',
    long_description=read_description(),
    long_description_content_type='text/markdown',
    author='Reserver Development Team',
    author_email='reserver@openscilab.com',
    url='https://github.com/openscilab/reserver',
    download_url='https://github.com/openscilab/reserver/tarball/v0.4',
    keywords="pypi pip package name reserve reserver reservation python",
    project_urls={
            'Source': 'https://github.com/openscilab/reserver',
    },
    install_requires=get_requires(),
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Manufacturing',
        'Intended Audience :: Science/Research',

    ],
    license='MIT',
    entry_points={
            'console_scripts': [
                'reserver = reserver.__main__:main',
            ]
    }
)
